@@ -1,7 +1,7 @@
 /* This is a generated file, see Makefile.am for its inputs. */
-static const char perm_strings[] = "chmod,fchmod,chown,lchown,fchown,setxattr,setxattrat,lsetxattr,fsetxattr,removexattr,removexattrat,lremovexattr,fremovexattr,fchownat,fchmodat,link,linkat\0execve\0readlink,quotactl,listxattr,listxattrat,llistxattr,flistxattr,getxattr,getxattrat,lgetxattr,fgetxattr,readlinkat,open,openat,openat2\0rename,mkdir,rmdir,creat,link,unlink,symlink,mknod,mkdirat,mknodat,unlinkat,renameat,linkat,symlinkat,renameat2,acct,swapon,quotactl,truncate,ftruncate,bind,fallocate,open,openat,openat2";
+static const char perm_strings[] = "chmod,fchmod,chown,lchown,fchown,setxattr,setxattrat,lsetxattr,fsetxattr,removexattr,removexattrat,lremovexattr,fremovexattr,fchownat,fchmodat,fchmodat2,file_setattr,link,linkat\0execve\0readlink,quotactl,listxattr,listxattrat,llistxattr,flistxattr,getxattr,getxattrat,lgetxattr,fgetxattr,readlinkat,open,openat,openat2,file_getattr\0rename,mkdir,rmdir,creat,link,unlink,symlink,mknod,mkdirat,mknodat,unlinkat,renameat,linkat,symlinkat,renameat2,acct,swapon,quotactl,quotactl_fd,truncate,ftruncate,bind,fallocate,open,openat,openat2";
 static const unsigned perm_s2i_s[] = {
-	0,155,162,295,
+	0,178,185,331,
 };
 static const int perm_s2i_i[] = {
 	8,1,4,2,
@@ -21,7 +21,7 @@ static int perm_s2i(const char *s, int *value) {
 	}
 }
 static const unsigned perm_i2s_direct[] = {
-	155,295,-1u,162,-1u,-1u,-1u,0,
+	178,331,-1u,185,-1u,-1u,-1u,0,
 };
 static const char *perm_i2s(int v) {
 	return i2s_direct__(perm_strings, perm_i2s_direct, 1, 8, v);
